package ez_api

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module EzSessionServer.SessionStoreInMemorySource

Implementation of session store in the server's memory.

Creates session from the specified information, generates random token, and associates session to the given token in storage.

Sourceval get_session : ?req:EzAPIServerUtils.Req.t -> string -> user_id EzSession.TYPES.session option Lwt.t

Looks up for the session associated with the given token. If req is also specified, then the returned session synchronizes its time with request.

Sourceval remove_session : user_id -> token:string -> unit Lwt.t

Removes session from session_by_token if user_id corresponds to session's one.